//缓存处理

/**
 * 获取本地缓存
 * function callback(cacheSize, errorInfo):
 */
function getCacheSize(callback) {
	var formatedSize;
	if(plus.os.name == "Android") {
		plus.android.importClass("java.io.File");
		formatedSize = formatSize(calcCache4Android());
		return callback(formatedSize, null);
	} else if(plus.os.name == "iOS") {
		calcCache(function(size) {
			formatedSize = formatSize(size);
			return callback(formatedSize, null);
		});
	} else {
		return callback(0, "未知的设备类型,无法计算缓存");
	}
}

function formatSize(size) {
	var fileSizeString;
	size = parseInt(size);
	outputLog("缓存大小：" + size);
	if(size <= 0) {
		fileSizeString = "0B";
	} else if(size < 1024) {
		fileSizeString = size + "B";
	} else if(size < 1048576) {
		fileSizeString = (size / 1024).toFixed(2) + "KB";
	} else if(size < 1073741824) {
		fileSizeString = (size / 1048576).toFixed(2) + "MB";
	} else {
		fileSizeString = (size / 1073741824).toFixed(2) + "GB";
	}
	return fileSizeString;
}
function calcCache4Android() {
	var cacheSize = 0;
	var main = plus.android.runtimeMainActivity();
	var sdRoot = main.getCacheDir();
	var files = plus.android.invoke(sdRoot, "listFiles");
	cacheSize += getFolderSize(files);
	return cacheSize;
}
function getFolderSize(files) {
	var size = 0;
	var len = files.length;
	for(var i = 0; i < len; i++) {
		// 如果下面还有文件
		if(files[i].isDirectory()) {
			var dirs = plus.android.invoke(files[i], "listFiles");
			size = size + getFolderSize(dirs);
		} else if(!files[i].isHidden()) {
			size = size + files[i].length();
		}
	}
	return size;
}

/**
 * 计算缓存大小  官方提供方法，用于iOS
 */
function calcCache(callback) {
	plus.cache.calculate(function(size) {
		var sizeInt = parseInt(size);
		return callback(sizeInt);
	});
}

/**
 * 清除缓存
 * callback():
 */
function clearCache(callback){
	if(plus.os.name == "Android") {
		clearCacheAndroid();
		return callback();
	} else if(plus.os.name == "iOS") {
		plus.cache.clear(callback);
	}
}
function clearCacheAndroid() {
	outputLog("清理所有缓存");
	plus.android.importClass("java.io.File");
	var main = plus.android.runtimeMainActivity();
	var sdRoot = main.getCacheDir();
	var files = plus.android.invoke(sdRoot, "listFiles");
	deleteDir(files);
}

function deleteDir(files) {
	var len = files.length;
	outputLog("len:" + len);
	for(var i = 0; i < len; i++) {
		outputLog("delete file dir:" + files[i]);
		// 如果下面还有文件
		if(files[i].isDirectory()) {
			var dirs = plus.android.invoke(files[i], "listFiles");
			deleteDir(dirs);
		} else if(!files[i].isHidden()) {
			files[i].delete();
		}
	}
}

/**
 * 清理localStorage
 */
function clearLocalAllCache(){
	plus.navigator.removeAllCookie();
	plus.cache.clear();
	if(plus.os.name == 'iOS'){
		plus.ios.invoke('NativeJsTool', "clearWkWebviewLocalStorage");
	}else{
		var WebStorage = plus.android.importClass("android.webkit.WebStorage");
		WebStorage.getInstance().deleteAllData();
	}
}
/*
 * iOS 清理缓存
 * 
 */
function iOSClearLocalStorage(cacheFile){
	if(!cacheFile) return;
	//WKWebview localStorage路径
	//cacheFileWebkit = cacheFile.split("Library/Caches")[0] + "Library/WebKit/WebsiteData/LocalStorage";
	var filenamagerobj = plus.ios.newObject("NSFileManager");
	//文件不存在 return
	if(!plus.ios.invoke(filenamagerobj, "subpathsAtPath:", cacheFile)) return;
	var childerFiles = plus.ios.invoke(filenamagerobj, "subpathsAtPath:", cacheFile);
	var length = plus.ios.invoke(childerFiles, "count");
	for(var i = 0; i < length; i++) {
		var fileName = plus.ios.invoke(childerFiles, "objectAtIndex:", i);
		if(!(fileName.indexOf("localstorage") >= 0)) {
			continue;
		}
		var absolutePath = cacheFile + "/" + fileName;
		plus.ios.invoke(filenamagerobj, "removeItemAtPath:error:", absolutePath, null);
	}
}
