/**
 * ===========================
 * 正则表达式工具
 * ===========================
 * 2017-03-14
 */


/**
 * 验证手机号
 * @param {Object} mobile
 */
function regexMobile(mobile) {
	//var regExp = new RegExp("^((14[0-9])|(16[0-9])|(19[0-9])|(17[0-9])|(13[0-9])|(15[0-9])|(18[0-9]))\\d{8}$");
	var regExp = new RegExp("^(1[0-9])\\d{9}$");
	return regExp.test(mobile);
}

/**
 * 验证普通电话、传真号码：可以“+”开头，除数字外，可含有“-” 
 * @param {Object} mobile
 */
function regexTel(tel) {
	var regExp = new RegExp("^[+]{0,1}(d){1,3}[ ]?([-]?((d)|[ ]){1,12})+$");
	return regExp.test(tel);
}

/**
 * 验证身份证
 * @param {Object} idCard
 */
function regexIdCard(idCard){
	var regExp15 = new RegExp("^[1-9]\\d{7}((0\\d)|(1[0-2]))(([0|1|2]\\d)|3[0-1])\\d{3}$");
	var regExp18 = new RegExp("^[1-9]\\d{5}[1-9]\\d{3}((0\\d)|(1[0-2]))(([0|1|2]\\d)|3[0-1])\\d{3}([0-9Xx])$");
	return regExp15.test(idCard) || regExp18.test(idCard);
}
/**
 * 验证银行卡号  13位到19位
 * @param {Object} idCard
 */
function regexBankCardNo(idCard){
	var regExp = new RegExp("^[1-9]\\d{12,18}$");
	return regExp.test(idCard);
}

/**
 * 校验登录名：只能输入5-20个以字母开头、可带数字、“_”、“.”的字串 
 * @param {Object} userName
 */
function regexUserName(userName){
	var regExp = new RegExp("^[a-zA-Z]{1}([a-zA-Z0-9]|[._]){4,19}$");
	return regExp.test(userName);
}

/**
 * 只能输入至少n位的数字，默认为2位
 * @param {Object} float
 * @param {Object} n
 */
function regexFloat(float, n){
	if(!n || n <= 0) n = 2;
	var regExp = new RegExp("^[0-9]+(.[0-9]{" + n + "})?$");
	return regExp.test(float);
}

/**
 * 只能输入汉字
 * @param {Object} str
 */
function regexChinese(str){
	var regExp = new RegExp("^[\u4e00-\u9fa5]{0,}$");
	return regExp.test(str);
}

/**
 * 验证邮箱地址
 * @param {Object} email
 */
function regexEmail(email){ 
	var regExp = new RegExp("^([a-zA-Z0-9_-])+@([a-zA-Z0-9_-])+(.[a-zA-Z0-9_-])");
	return regExp.test(email);
}

/**
 * 验证网址地址
 * @param {Object} email
 */
function regexHttpUrl(httpUrl){
	var regExp = new RegExp("^http://([\w-]+\.)+[\w-]+(/[\w-./?%&=]*)?$");
	return regExp.test(httpUrl);
}

/**
 * 验证字符串是否为空或者是空格
 * @param {Object} string
 */
function stringIsNull( str ){
	if ( str == "" ) return true;
	if ( str == null ) return true;
	if ( str.length == 0) return true;
	var regu = "^[ ]+$";
	var re = new RegExp(regu);
	return re.test(str);
}

/**
 * 验证是否包含特殊字符
 * @param {Object} string
 */
function stringIsSpecial( str ){
	if ( str == "" ) return true;
	if ( str == null ) return true;
	if ( str.length == 0) return true;
	var regu = "^[\u4e00-\u9fa5_a-zA-Z0-9]+$";
	var re = new RegExp(regu);
	return !re.test(str);
}

/**
 * 验证只有数字
 * @param {Object} string
 */
function stringIsNumber( str ){
	if ( str == "" ) return false;
	if ( str == null ) return false;
	if ( str.length == 0) return false;
	var regu = "^[0-9]+$";
	var re = new RegExp(regu);
	return re.test(str);
}

/**
 * 验证只有字母
 * @param {Object} string
 */
function stringIsLetter( str ){
	if ( str == "" ) return true;
	if ( str == null ) return true;
	if ( str.length == 0) return true;
	var regu = "^[A-Za-z]+$";
	var re = new RegExp(regu);
	return re.test(str);
}

/**
 * 验证为小数
 * @param {Object} string
 */
function stringIsDouble( str ){
	if ( str == "" ) return false;
	if ( str == null ) return false;
	if ( str.length == 0) return false;
	var regu = "^[0-9.]+$";
	var re = new RegExp(regu);
	return re.test(str);
}

/**
 * 验证只有字母和数字
 * @param {Object} string
 */
function stringIsNumberOrLetter( str ){
	if ( str == "" ) return true;
	if ( str == null ) return true;
	if ( str.length == 0) return true;
	var regu = "^[A-Za-z0-9]+$";
	var re = new RegExp(regu);
	return re.test(str);
}

/**
 * 验证两种字符以上，且为8位到20位
 * @param {Object} string
 */
function stringIsRightPwd( str ){
	if ( str == "" ) return true;
	if ( str == null ) return true;
	if ( str.length == 0) return true;
	var regu = "^(?![0-9]+$)(?![a-zA-Z]+$)(?!([^(0-9a-zA-Z)]|[\(\)])+$)([^(0-9a-zA-Z)]|[\(\)]|[a-zA-Z]|[0-9]){8,20}$";
	var re = new RegExp(regu);
	return re.test(str);
}

/**
 * 将emoji表情替换为指定字符串（默认替换为[表情]）
 * @param {Object} str
 * @param {Object} replaceStr
 */
function replaceEmojiToStr(str, replaceStr) {
	if(!str) return str;
	if(replaceStr == null){
		replaceStr = '[表情]';
	}
	var regStr = /\ud83c[\udf00-\udfff]|\ud83d[\udc00-\ude4f]|\ud83d[\ude80-\udeff]/ig;
	return str.replace(regStr, replaceStr);
}

/**
 * 禁止输入框输入emoji表情
 * @param {Object} str
 * @return {Object} isReplace 是否进行了替换 content 替换的结果
 */
function prohibitInputEmoji(str) {
	if(!str) return str;
	var regStr = /[\uD83C|\uD83D|\uD83E][\uDC00-\uDFFF][\u200D|\uFE0F]|[\uD83C|\uD83D|\uD83E][\uDC00-\uDFFF]|[0-9|*|#]\uFE0F\u20E3|[0-9|#]\u20E3|[\u203C-\u3299]\uFE0F\u200D|[\u203C-\u3299]\uFE0F|[\u2122-\u2B55]|\u303D|[\A9|\AE]\u3030|\uA9|\uAE|\u3030/ig;
	if(str.match(regStr)) {
		str = str.replace(regStr, '');
		return {isReplace : true, content:str};
	} else {
		return {isReplace : false};
	}
	
}
