/*
 * 摘自h5+官方文档的分享注意事项
 * pictures: (Array[ String ] 类型 )分享消息的图片
 * 分享消息中包含的图片路径，仅支持本地路径。 
 * 若分享平台仅支持提交一张图片，传入多张图片则仅提交第一张图片。
 * 如果不能同时支持其它内容信息，优先级顺序为：pictures>content。
 * 
 * thumbs: (Array[ Stromg ] 类型 )分享消息的缩略图
 * 分享消息中包含的缩略图路径，支持本地路径及网络路径。
 * 若分享平台仅支持提交一张图片，传入多张图片则仅提交第一张图片。
 * 如果分享平台的信息不支持缩略图，若没有设置消息的图片（pictures）则使用缩略图，否则忽略其属性值。
 * 注意：图片有大小限制，推荐图片小于20Kb。
 */
var shares = {};
var openWebview;
/**
 * 初始化分享服务
 */
function initShareServices(webview) {
	openWebview = webview;
	plus.share.getServices(function(services) {
		for(var i in services) {
			var service = services[i];
			shares[service.id] = service;
		}
	}, function(e) {
	});
}

/*
 * 是否安装了微信客户端
 * 登录页面调用
 */
function initShareServicesAndInstalledWechat(webview, callback){
	openWebview = webview;
	plus.share.getServices(function(services) {
		for(var i in services) {
			var service = services[i];
			shares[service.id] = service;
		}
		var wechatShare = shares['weixin'];
		if(!wechatShare) return;
		if(!wechatShare.nativeClient) {
			callback(false);
		}else {
			callback(true);
		}
	}, function(e) {
		callback(false);
	});
}

/**
 * 微信登录 
 */
function onWechatLogin(){
	var share = shares['weixin'];
	if(!share) {
		toast("初始化微信服务失败");
		return;
	}
	if(share && !share.nativeClient) {
		toast("未安装微信客户端");
		return;
	}
	// 扩展API加载完毕，现在可以正常调用扩展API
	plus.oauth.getServices( function(services){
		var auths = services;
		var s;//0小米 1QQ 2新浪 3微信
		for(var i= 0; i< auths.length; i++){
			s = auths[i];
			if(s.id == "weixin"){
				break;
			}
		}
		if(!s || s.id != 'weixin'){
			toast("初始化微信服务失败");
			return;
		}
		if (!s.authResult) {
			s.login( function(e){
				getWechatUserInfo(s);
			}, function(e){
			});
		}else{
			getWechatUserInfo(s);
		}
	}, function(e){
		toast( "获取服务列表失败");
	});
}

/**
 * 获取微信登录用户信息
 */
function getWechatUserInfo(user){
	user.getUserInfo( function(e){
		outputLog( "获取用户信息成功："+JSON.stringify(user.userInfo) );
		//调用webview不为空，则通知登录成功
		if(openWebview){
			mui.fire(openWebview, "onWechatLoginCallSuccessListener", user.userInfo);	
		}
	}, function(e){
		outputLog( "获取用户信息失败："+e.message+" - "+e.code );
	} );
}
/*
 * 调用微信小程序
 */
function openWxMiniProgram(id, path, type, webUrl){
	var share = shares['weixin'];
	if(!share) {
		toast("初始化微信服务失败");
		return;
	}
	if(share && !share.nativeClient) {
		toast("未安装微信客户端");
		return;
	}
	var param = {id:id};
	if(path) param.path = path; 
	if(type >= 0) param.type = type;
	if(webUrl) param.webUrl = webUrl;
	share.launchMiniProgram(param);
}

/**
 * QQ分享
 * @param {Object} params
 * href 分享链接, title 分享标题,
 * content 分享文字内容, imgUrl 分享图片地址
 */
function shareToQQ(params) {
	var share = shares['qq'];
	if(share == null) {
		toast("获取QQ分享服务失败");
		return;
	}
	if(!share.nativeClient) {
		toast("未安装QQ客户端");
		return;
	}
	if(!params.href) params.href = "https://h5.xiaofubao.com/dms";
	var msg = {
		"href": params.href,
		"title": params.title,
		"content": params.content,
		"thumbs": [params.imgUrl]
	};
	//分享图片类型
	if(params.type == 'image'){
		msg = {};
		msg.type = "image";
		msg.pictures = [params.imgUrl];
	}
	callShare(msg, share);
}

/**
 * 微信好友分享
 * @param {Object} params
 * href 分享链接, title 分享标题,
 * content 分享文字内容, imgUrl 分享图片地址
 */
function shareToWeixin(params) {
	var share = shares['weixin'];
	if(share == null) {
		toast("获取微信分享服务失败");
		return;
	}
	if(!share.nativeClient) {
		toast("未安装微信客户端");	
		return;
	}
	// iOS分享到微信的图片大小有限制，压缩图片再分享 本地图片不需要压缩
	if(plus.os.name == 'iOS' && params.imgUrl.indexOf("http") == 0) {
		params.imgUrl = picClipSize(params.imgUrl);
	}
	if(!params.href) params.href = "https://h5.xiaofubao.com/dms";
	var msg = {
		"extra": {
			"scene": 'WXSceneSession'
		},
		"href": params.href,
		"title": params.title,
		"content": params.content,
		"thumbs": [params.imgUrl]
	};
	//分享图片类型
	if(params.type == 'image'){
		msg.type = "image";
		msg.pictures = [params.imgUrl];
	}
	callShare(msg, share);
}

/**
 * 微信朋友圈分享
 * 朋友圈只有“图+文”或者纯文字模式分享
 * @param {Object} params
 * href 分享链接, content 分享文字内容, imgUrl 分享图片地址
 */
function shareToWeixinGroup(params) {
	var share = shares['weixin'];
	if(share == null) {
		toast("获取微信分享服务失败");
		return;
	}
	if(!share.nativeClient) {
		toast("未安装微信客户端");
		return;
	}
	// iOS分享到微信的图片大小有限制，压缩图片再分享 本地图片不需要压缩
	if(plus.os.name == 'iOS' && params.imgUrl.indexOf("http") == 0) {
		params.imgUrl = picClipSize(params.imgUrl);
	}
	
	if(!params.href) params.href = "https://h5.xiaofubao.com/dms";
	var msg = {
		"extra": {
			"scene": 'WXSceneTimeline'
		},
		"href": params.href,
		"title": params.title + " " + params.content,
		"thumbs": [params.imgUrl]
	};
	//社团分享到朋友圈只需要content 不要title
	if(params.href && params.href.indexOf("/club/h5/detail?id=") > 0){
		msg.title = params.content.substring(0, 5)+ "-" + params.content.substring(5, params.content.length);
	}
	//分享图片类型
	if(params.type == 'image'){
		msg.type = "image";
		msg.pictures = [params.imgUrl];
	}
	callShare(msg, share);
}

/**
 * 微博分享
 * 微博分享图片仅支持本地路径 *微博后面可以支持网络路径图片
 */
function shareToWeibo(params) {
	var share = shares['sinaweibo'];
	if(share == null) {
		toast("获取新浪微博分享服务失败");
		return;
	}
	if(!share.nativeClient && plus.os.name == "iOS") {
		toast("未安装微博客户端");
		return;
	}
	if(!params.imgUrl || params.imgUrl.indexOf("http") < 0){
		var msg = {
			"content": params.title + " " + params.content + params.href,
			"pictures": [params.imgUrl]
		};
		//分享图片类型
		if(params.type == 'image'){
			msg.type = "image";
		}
		callShare(msg, share);
		return;
	}
	showWaiting();	
	plus.downloader.createDownload(params.imgUrl, {
		filename: "_doc/images/"
	}, function(d, status) {
		closeWaiting();
		if(status != 200) return;
		if(!params.href) params.href = "https://h5.xiaofubao.com/dms";
		var msg = {
			"content": params.title + " " + params.content + params.href,
			"pictures": [d.filename]
		};
		//分享图片类型
		if(params.type == 'image'){
			msg.type = "image";
		}
		callShare(msg, share);
	}).start();
}

/**
 * 调用分享功能 
 */
function callShare(msg, share) {
	// 发送分享
	if(share.authenticated) {
		shareMessage(msg, share);
		return;
	}
	share.authorize(function() {
		shareMessage(msg, share);
	}, function(e) {
		toast('分享认证授权失败');
		outputLog('认证授权失败：' + e.code + ' - ' + e.message);
	});
}

/**
 * 发送分享消息
 * @param {JSON} msg
 * @param {plus.share.ShareService} share
 */
function shareMessage(msg, share) {
	mui("#morePopover").popover('toggle');
	share.send(msg, function() {
		toast('分享成功');
		//调用webview不为空，则通知
		if(openWebview) mui.fire(openWebview, "onShareSuccessListener", {});
	}, function(e) {
		outputLog('分享到"' + share.description + '"失败: ' + JSON.stringify(e));
		if(e.code == -2 || new RegExp("Share微信分享:-2") || new RegExp("Share微信分享:-3").test(e.message)) { // 用户取消
			return;
		}
		toast('分享失败');
	});
	//调用webview不为空，则通知点击分享调用成功
	if(openWebview) mui.fire(openWebview, "onShareCallSuccessListener", {});
}

/**
 * 裁剪分享的缩略图大小
 * @param {Object} imageUrl
 */
function picClipSize(imageUrl) {
	var NativeJsTool = plus.ios.newObject("NativeJsTool");
	NativeJsTool.plusSetAttribute("orishareImg", imageUrl);
	plus.ios.invoke(NativeJsTool, "scaleToWidth");
	var finImgPath = "file://" + NativeJsTool.plusGetAttribute('finShareImg');
	return finImgPath;
}